@@ -232,7 +232,7 @@ def get_full_file_list_df(dirName:str)->pd.DataFrame:
                 dir_list.append(full_path)
             else:
                 file_details = get_file_details(full_path)
-                dffiles.loc[len(dffiles)] = [dir, entry, file_details[0][0], file_details[1][0],
+                dffiles.loc[len(dffiles)] = [dir, entry, file_details[0], file_details[1],
                     file_details[2]]
     return dffiles
 
